@@ -31,14 +31,16 @@
 #' @return a graph object of class
 #' \code{dgr_graph}.
 #' @examples
-#' # Create a graph with 8 nodes and 7 edges
+#' # Create a graph with 8
+#' # nodes and 7 edges
 #' graph <-
 #'   create_graph() %>%
 #'   add_path(n = 8) %>%
 #'   set_node_attrs(
 #'     node_attr = weight,
-#'     values = c(8.2, 3.7, 6.3, 9.2,
-#'                1.6, 2.5, 7.2, 5.4))
+#'     values = c(
+#'       8.2, 3.7, 6.3, 9.2,
+#'       1.6, 2.5, 7.2, 5.4))
 #'
 #' # Find group membership values for all nodes
 #' # in the graph through the Walktrap community
@@ -47,15 +49,15 @@
 #' # with the `join_node_attrs()` function
 #' graph <-
 #'   graph %>%
-#'   join_node_attrs(df = get_cmty_walktrap(.))
+#'   join_node_attrs(
+#'     df = get_cmty_walktrap(.))
 #'
 #' # Inspect the number of distinct communities
-#' get_node_attrs(
-#'   graph = graph,
-#'   node_attr = walktrap_group) %>%
+#' graph %>%
+#'   get_node_attrs(
+#'     node_attr = walktrap_group) %>%
 #'   unique() %>%
 #'   sort()
-#' #> [1] 1 2 3
 #'
 #' # Visually distinguish the nodes in the different
 #' # communities by applying colors using the
@@ -77,16 +79,8 @@
 #'     alpha = 80)
 #'
 #' # Show the graph's internal node data frame
-#' get_node_df(graph)
-#' #>   id type label weight walktrap_group fillcolor     color
-#' #> 1  1 <NA>     1    8.2              1 #E5F5E090 #44015480
-#' #> 2  2 <NA>     2    3.7              1 #E5F5E090 #44015480
-#' #> 3  3 <NA>     3    6.3              1 #E5F5E090 #44015480
-#' #> 4  4 <NA>     4    9.2              3 #31A35490 #FDE72580
-#' #> 5  5 <NA>     5    1.6              3 #31A35490 #FDE72580
-#' #> 6  6 <NA>     6    2.5              2 #A1D99B90 #21908C80
-#' #> 7  7 <NA>     7    7.2              2 #A1D99B90 #21908C80
-#' #> 8  8 <NA>     8    5.4              2 #A1D99B90 #21908C80
+#' graph %>%
+#'   get_node_df()
 #'
 #' # Create a graph with 8 nodes and 7 edges
 #' graph <-
@@ -94,8 +88,9 @@
 #'   add_path(n = 8) %>%
 #'   set_node_attrs(
 #'     node_attr = weight,
-#'     values = c(8.2, 3.7, 6.3, 9.2,
-#'                1.6, 2.5, 7.2, 5.4))
+#'     values = c(
+#'       8.2, 3.7, 6.3, 9.2,
+#'       1.6, 2.5, 7.2, 5.4))
 #'
 #' # We can bucketize values in `weight` using
 #' # `cut_points` and assign colors to each of the
@@ -111,19 +106,11 @@
 #' # Now there will be a `fillcolor` node attribute
 #' # with distinct colors (the `#D9D9D9` color is
 #' # the default `gray85` color)
-#' get_node_df(graph)
-#' #>   id type label weight fillcolor
-#' #> 1  1 <NA>     1    8.2   #2B83BA
-#' #> 2  2 <NA>     2    3.7   #FDAE61
-#' #> 3  3 <NA>     3    6.3   #ABDDA4
-#' #> 4  4 <NA>     4    9.2   #D9D9D9
-#' #> 5  5 <NA>     5    1.6   #D7191C
-#' #> 6  6 <NA>     6    2.5   #D7191C
-#' #> 7  7 <NA>     7    7.2   #2B83BA
-#' #> 8  8 <NA>     8    5.4   #ABDDA4
+#' graph %>%
+#'   get_node_df()
 #' @import RColorBrewer
 #' @importFrom viridis viridis
-#' @importFrom rlang enquo UQ
+#' @importFrom rlang enquo UQ get_expr
 #' @export colorize_node_attrs
 
 colorize_node_attrs <- function(graph,
@@ -138,17 +125,25 @@ colorize_node_attrs <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
-  node_attr_from <- rlang::enquo(node_attr_from)
-  node_attr_from <- (rlang::UQ(node_attr_from) %>% paste())[2]
-
-  node_attr_to <- rlang::enquo(node_attr_to)
-  node_attr_to <- (rlang::UQ(node_attr_to) %>% paste())[2]
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
 
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
+  # Get the requested `node_attr_from`
+  node_attr_from <-
+    rlang::enquo(node_attr_from) %>% rlang::get_expr() %>% as.character()
+
+  # Get the requested `node_attr_to`
+  node_attr_to <-
+    rlang::enquo(node_attr_to) %>% rlang::get_expr() %>% as.character()
+
   # Extract ndf from graph
   nodes_df <- graph$nodes_df
 
@@ -177,7 +172,10 @@ colorize_node_attrs <- function(graph,
     if (!(palette %in%
           c(row.names(RColorBrewer::brewer.pal.info),
             "viridis"))) {
-      stop("The color palette is not an RColorBrewer or viridis palette.")
+
+      emit_error(
+        fcn_name = fcn_name,
+        reasons = "The color palette is not an `RColorBrewer` or `viridis` palette")
     }
   }
 
@@ -277,7 +275,7 @@ colorize_node_attrs <- function(graph,
   # in selection
   graph <-
     set_node_attrs(
-      x = graph,
+      graph = graph,
       node_attr = rlang::UQ(node_attr_to_2),
       values = nodes_attr_vector_colorized)
 
@@ -289,7 +287,7 @@ colorize_node_attrs <- function(graph,
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "colorize_node_attrs",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
