@@ -3,8 +3,8 @@
 #' node pairs. This works for directed graphs.
 #' @param graph a graph object of class
 #' \code{dgr_graph}.
-#' @return a single numeric value representing the
-#' number of unconnected node pairs.
+#' @return a single numeric value representing
+#' the number of unconnected node pairs.
 #' @examples
 #' # Create a cycle graph
 #' graph <-
@@ -13,23 +13,28 @@
 #'
 #' # Get a count of unconnected node
 #' # pairs in the graph
-#' count_unconnected_node_pairs(graph)
-#' #> [1] 5
+#' graph %>%
+#'   count_unconnected_node_pairs()
 #'
 #' # Create a full graph and then
 #' # count all unconnected node pairs
 #' create_graph() %>%
 #'   add_full_graph(n = 10) %>%
 #'   count_unconnected_node_pairs()
-#' #> [1] 0
 #' @importFrom igraph dyad_census
 #' @export count_unconnected_node_pairs
 
 count_unconnected_node_pairs <- function(graph) {
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # If the graph is empty, then return NA
