@@ -8,38 +8,39 @@
 #' @return a graph object of class
 #' \code{dgr_graph}.
 #' @examples
-#' # Create a random graph
 #' graph <-
-#'   create_random_graph(
-#'     n = 5, m = 10,
-#'     set_seed = 23)
+#'   create_graph() %>%
+#'   add_gnm_graph(
+#'     n = 5,
+#'     m = 10,
+#'     set_seed = 23) %>%
+#'  set_node_attrs(
+#'     node_attr = value,
+#'     values = rnorm(
+#'       n = count_nodes(.),
+#'       mean = 5,
+#'       sd = 1) %>% round(1))
 #'
-#' # Get the graph's internal ndf to show
-#' # which node attributes are available
-#' get_node_df(graph)
-#' #>   id type label value
-#' #> 1  1 <NA>     1   6.0
-#' #> 2  2 <NA>     2   2.5
-#' #> 3  3 <NA>     3   3.5
-#' #> 4  4 <NA>     4   7.5
-#' #> 5  5 <NA>     5   8.5
+#' # Get the graph's internal
+#' # ndf to show which node
+#' # attributes are available
+#' graph %>%
+#'   get_node_df()
 #'
-#' # Drop the `value` node attribute
+#' # Drop the `value` node
+#' # attribute
 #' graph <-
 #'   graph %>%
 #'   drop_node_attrs(
 #'     node_attr = value)
 #'
-#' # Get the graph's internal ndf to show that
-#' # the node attribute `value` had been removed
-#' get_node_df(graph)
-#' #>   id type label
-#' #> 1  1 <NA>     1
-#' #> 2  2 <NA>     2
-#' #> 3  3 <NA>     3
-#' #> 4  4 <NA>     4
-#' #> 5  5 <NA>     5
-#' @importFrom rlang enquo UQ
+#' # Get the graph's internal
+#' # ndf to show that the node
+#' # attribute `value` had been
+#' # removed
+#' graph %>%
+#'   get_node_df()
+#' @importFrom rlang enquo get_expr
 #' @export drop_node_attrs
 
 drop_node_attrs <- function(graph,
@@ -48,25 +49,38 @@ drop_node_attrs <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
-  node_attr <- rlang::enquo(node_attr)
-  node_attr <- (rlang::UQ(node_attr) %>% paste())[2]
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
 
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
+  # Get the requested `node_attr`
+  node_attr <-
+    rlang::enquo(node_attr) %>% rlang::get_expr() %>% as.character()
+
   # Stop function if length of `node_attr` is
   # greater than one
   if (length(node_attr) > 1) {
-    stop("You can only provide a single column.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "You can only provide a single column")
   }
 
   # Stop function if `node_attr` is any of
   # `nodes`, `node`, `type`, or `label`
   if (any(c("nodes", "node", "type", "label") %in%
           node_attr)) {
-    stop("You cannot drop this column.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "You cannot drop this column")
   }
 
   # Extract the graph's ndf
@@ -78,7 +92,10 @@ drop_node_attrs <- function(graph,
   # Stop function if `node_attr` is not one
   # of the graph's column
   if (!any(column_names_graph %in% node_attr)) {
-    stop("The node attribute to drop is not in the ndf.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The node attribute to drop is not in the ndf")
   }
 
   # Get the column number for the node attr to drop
@@ -96,7 +113,7 @@ drop_node_attrs <- function(graph,
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "drop_node_attrs",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
