@@ -5,39 +5,50 @@
 #' \code{dgr_graph}.
 #' @return a vector of node IDs.
 #' @examples
-#' # Create a random graph and make every node
-#' # shape a `square`
+#' # Create a random graph using the
+#' # `add_gnm_graph()` function
 #' graph <-
-#'   create_random_graph(
-#'     n = 30, m = 50,
+#'   create_graph() %>%
+#'   add_gnm_graph(
+#'     n = 10,
+#'     m = 12,
 #'     set_seed = 23) %>%
 #'   set_node_attrs(
-#'     node_attr = "shape",
+#'     node_attr = shape,
 #'     values = "square")
 #'
-#' # Get the articulation points in the graph (i.e.,
-#' # those nodes that if any were to be removed, the
-#' # graph would become disconnected)
-#' get_articulation_points(graph)
-#' #> [1]  9 10 12 19 22 26 30
+#' # Get the articulation points
+#' # in the graph (i.e., those
+#' # nodes that if any were to be
+#' # removed, the graph would
+#' # become disconnected)
+#' graph %>%
+#'   get_articulation_points()
 #'
-#' # For the articulation points, change the node
-#' # shape to a `circle`
+#' # For the articulation points,
+#' # change the node shape to
+#' # a `circle`
 #' graph <-
 #'   graph %>%
 #'   select_nodes_by_id(
 #'     nodes = get_articulation_points(.)) %>%
 #'   set_node_attrs_ws(
-#'     node_attr = "shape",
+#'     node_attr = shape,
 #'     value = "circle")
 #' @importFrom igraph articulation_points as_ids
 #' @export get_articulation_points
 
 get_articulation_points <- function(graph) {
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Convert the graph to an igraph object
