@@ -5,7 +5,7 @@
 #' \code{dgr_graph}.
 #' @return an edge data frame.
 #' @examples
-#' # Create a graph using several piped functions
+#' # Create a graph
 #' graph <-
 #'   create_graph() %>%
 #'   add_n_nodes(
@@ -16,7 +16,8 @@
 #'     n = 5,
 #'     direction = "from",
 #'     type = "b") %>%
-#'   select_edges_by_node_id(nodes = 3:5) %>%
+#'   select_edges_by_node_id(
+#'     nodes = 3:5) %>%
 #'   set_edge_attrs_ws(
 #'     edge_attr = color,
 #'     value = "green") %>%
@@ -32,21 +33,23 @@
 #'     value = "b") %>%
 #'   clear_selection()
 #'
-#' # Get the graph's internal edge data frame (edf)
-#' get_edge_df(graph)
-#' #>   id from to rel color
-#' #> 1  1    1  2   b  blue
-#' #> 2  2    1  3   a green
-#' #> 3  3    1  4   a green
-#' #> 4  4    1  5   a green
-#' #> 5  5    1  6   b  blue
+#' # Get the graph's internal
+#' # edge data frame (edf)
+#' graph %>%
+#'   get_edge_df()
 #' @export get_edge_df
 
 get_edge_df <- function(graph) {
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   graph$edges_df
