@@ -33,8 +33,8 @@
 #'     edges_df = edf)
 #'
 #' # Get a vector of all edges in a graph
-#' get_edge_ids(graph)
-#' #> [1] 1 2 3
+#' graph %>%
+#'   get_edge_ids()
 #'
 #' # Get a vector of edge ID values using a
 #' # numeric comparison (i.e., all edges with
@@ -42,7 +42,6 @@
 #' get_edge_ids(
 #'   graph,
 #'   conditions = value > 3)
-#' #> [1] 1 3
 #'
 #' # Get a vector of edge ID values using
 #' # a match pattern (i.e., all edges with
@@ -50,7 +49,6 @@
 #' get_edge_ids(
 #'   graph,
 #'   conditions = color == "pink")
-#' #> [1] 1
 #'
 #' # Use multiple conditions to return edges
 #' # with the desired attribute values
@@ -59,14 +57,17 @@
 #'   conditions =
 #'     color == "blue" &
 #'     value > 5)
-#' #> [1] 3
 #' @importFrom dplyr filter pull
-#' @importFrom rlang enquo UQ
+#' @importFrom rlang enquo UQ get_expr
 #' @export get_edge_ids
 
 get_edge_ids <- function(graph,
                          conditions = NULL) {
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
+  # Capture provided conditions
   conditions <- rlang::enquo(conditions)
 
   # Create binding for a specific variable
@@ -83,7 +84,9 @@ get_edge_ids <- function(graph,
   # If conditions are provided then
   # pass in those conditions and filter the
   # data frame of `edges_df`
-  if (!((rlang::UQ(conditions) %>% paste())[2] == "NULL")) {
+  if (!is.null(
+    rlang::enquo(conditions) %>%
+    rlang::get_expr())) {
 
     edges_df <-
       filter(
