@@ -7,11 +7,15 @@
 #' \code{dgr_graph}.
 #' @return a \code{df_tbl} object.
 #' @examples
-#' # Create a random graph and
-#' # remove two nodes from it
+#' # Create a random graph using the
+#' # `add_gnm_graph()` function and
+#' # delete 2 nodes from the graph
 #' graph <-
-#'   create_random_graph(
-#'     n = 10, m = 22,
+#'   create_graph(
+#'     directed = FALSE) %>%
+#'   add_gnm_graph(
+#'     n = 10,
+#'     m = 15,
 #'     set_seed = 23) %>%
 #'   delete_node(node = 5) %>%
 #'   delete_node(node = 7)
@@ -20,26 +24,22 @@
 #' # record of all graph transformations
 #' graph %>%
 #'   get_graph_log()
-#' #> # A tibble: 3 x 6
-#' #>   version_id       function_used
-#' #>        <int>               <chr>
-#' #> 1          1 create_random_graph
-#' #> 2          2         delete_node
-#' #> 3          3         delete_node
-#' #> # ... with 4 more variables:
-#' #> #   time_modified <dttm>,
-#' #> #   duration <dbl>, nodes <int>,
-#' #> #   edges <int>
-#' @importFrom tibble as_tibble
+#' @importFrom dplyr as_tibble
 #' @export get_graph_log
 
 get_graph_log <- function(graph) {
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   graph$graph_log %>%
-    tibble::as_tibble()
+    dplyr::as_tibble()
 }
