@@ -18,19 +18,22 @@
 #' @return a matrix with Jaccard similarity values
 #' for each pair of nodes considered.
 #' @examples
-#' # Create a random graph
+#' # Create a random graph using the
+#' # `add_gnm_graph()` function
 #' graph <-
-#'   create_random_graph(
-#'     n = 10, m = 22,
+#'   create_graph(
+#'     directed = FALSE) %>%
+#'   add_gnm_graph(
+#'     n = 10,
+#'     m = 15,
 #'     set_seed = 23)
 #'
-#' # Get the Jaccard similarity values for
-#' # nodes `5`, `6`, and `7`
-#' get_jaccard_similarity(graph, nodes = 5:7)
-#' #>       5     6     7
-#' #> 5 1.000 0.333 0.286
-#' #> 6 0.333 1.000 0.375
-#' #> 7 0.286 0.375 1.000
+#' # Get the Jaccard similarity
+#' # values for nodes `5`, `6`,
+#' # and `7`
+#' graph %>%
+#'   get_jaccard_similarity(
+#'     nodes = 5:7)
 #' @importFrom igraph similarity V
 #' @export get_jaccard_similarity
 
@@ -39,16 +42,25 @@ get_jaccard_similarity <- function(graph,
                                    direction = "all",
                                    round_to = 3) {
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Ensure that values provided for the
   # `direction` argument are from the
   # valid options
   if (!(direction %in% c("all", "in", "out"))) {
-    stop("Valid options for `direction` are `all`, `in`, or `out`.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "Valid options for `direction` are `all`, `in`, or `out`")
   }
 
   # Convert the graph to an igraph object
@@ -63,7 +75,10 @@ get_jaccard_similarity <- function(graph,
     # Stop function if nodes provided not in
     # the graph
     if (!all(nodes %in% get_node_ids(graph))) {
-      stop("One or more nodes provided not in graph.")
+
+      emit_error(
+        fcn_name = fcn_name,
+        reasons = "One or more nodes provided not in graph")
     }
 
     # Get an igraph representation of node ID values
