@@ -1,11 +1,12 @@
 #' Get a node data frame from a graph
-#' @description From a graph, obtain a node data frame
-#' with all current node attributes.
+#' @description From a graph, obtain a
+#' node data frame with all current
+#' node attributes.
 #' @param graph a graph object of class
 #' \code{dgr_graph}.
 #' @return a node data frame.
 #' @examples
-#' # Create a graph using several piped functions
+#' # Create a graph
 #' graph <-
 #'   create_graph() %>%
 #'   add_n_nodes(
@@ -16,12 +17,14 @@
 #'     n = 5,
 #'     direction = "from",
 #'     type = "b") %>%
-#'   select_nodes_by_id(nodes = 1) %>%
+#'   select_nodes_by_id(
+#'     nodes = 1) %>%
 #'   set_node_attrs_ws(
 #'     node_attr = value,
 #'     value = 25.3) %>%
 #'   clear_selection() %>%
-#'   select_nodes_by_id(nodes = 2:4) %>%
+#'   select_nodes_by_id(
+#'     nodes = 2:4) %>%
 #'   set_node_attrs_ws(
 #'     node_attr = color,
 #'     value = "grey70") %>%
@@ -33,21 +36,21 @@
 #'
 #' # Get the graph's internal node
 #' # data frame (ndf)
-#' get_node_df(graph)
-#' #>   id type label value  color
-#' #> 1  1    a  <NA>  25.3 grey80
-#' #> 2  2    b  <NA>    NA grey70
-#' #> 3  3    b  <NA>    NA grey70
-#' #> 4  4    b  <NA>    NA grey70
-#' #> 5  5    b  <NA>    NA grey80
-#' #> 6  6    b  <NA>    NA grey80
+#' graph %>%
+#'   get_node_df()
 #' @export get_node_df
 
 get_node_df <- function(graph) {
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   graph$nodes_df
