@@ -6,23 +6,29 @@
 #' \code{dgr_graph}.
 #' @return a vector of node IDs.
 #' @examples
-#' \dontrun{
-#' # Get the nodes that are in the graph periphery
-#' # of a randomly-created graph
-#' create_random_graph(
-#'     n = 15, m = 24,
+#' # Create a random graph using the
+#' # `add_gnm_graph()` function and
+#' # get the nodes in the graph periphery
+#' create_graph() %>%
+#'   add_gnm_graph(
+#'     n = 28,
+#'     m = 35,
 #'     set_seed = 23) %>%
 #'   get_periphery()
-#' #> [1] 3 6
-#' }
 #' @importFrom dplyr filter pull
 #' @export get_periphery
 
 get_periphery <- function(graph) {
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Create bindings for specific variables
