@@ -27,53 +27,63 @@
 #' neighboring node similarity to the starting node.
 #' @return a vector of node ID values.
 #' @examples
-#' # Getting similar neighbors can be done through
-#' # numerical comparisons; start with creating a
-#' # random, directed graph with 18 nodes and 22 edges
+#' # Getting similar neighbors can
+#' # be done through numerical comparisons;
+#' # start by creating a random, directed
+#' # graph with 18 nodes and 22 edges
+#' # using the `add_gnm_graph()` function
 #' graph <-
-#'   create_random_graph(
-#'     n = 18, m = 22,
-#'     set_seed = 23)
+#'   create_graph() %>%
+#'   add_gnm_graph(
+#'     n = 18,
+#'     m = 25,
+#'     set_seed = 23) %>%
+#'   set_node_attrs(
+#'     node_attr = value,
+#'     values = rnorm(
+#'       n = count_nodes(.),
+#'       mean = 5,
+#'       sd = 1) %>% round(0))
 #'
-#' # The `create_random_graph()` function randomly
-#' # assigns numerical values to all nodes (as the
-#' # `value` attribute) from 0 to 10 and to 1 decimal
-#' # place. By starting with node (`8`), we can test
-#' # whether any nodes adjacent and beyond are
+#' # Starting with node `10`, we
+#' # can test whether any nodes
+#' # adjacent and beyond are
 #' # numerically equivalent in `value`
 #' graph %>%
 #'   get_similar_nbrs(
-#'     node = 8,
-#'     node_attr = "value")
-#' #> [1] 7 10
+#'     node = 10,
+#'     node_attr = value)
 #'
-#' # We can also set a tolerance for ascribing
-#' # similarly by using either the `tol_abs` or
-#' # `tol_pct` arguments (the first applies absolute
-#' # lower and upper bounds from the value in the
-#' # starting node and the latter uses a percentage
-#' # difference to do the same); try setting `tol_abs`
-#' # with a fairly large range to determine if several
-#' # nodes can be selected
+#' # We can also set a tolerance
+#' # for ascribing similarly by using
+#' # either the `tol_abs` or `tol_pct`
+#' # arguments (the first applies absolute
+#' # lower and upper bounds from the
+#' # value in the starting node and the
+#' # latter uses a percentage difference
+#' # to do the same); try setting `tol_abs`
+#' # with a fairly large range to
+#' # determine if several nodes can be
+#' # selected
 #' graph %>%
 #'   get_similar_nbrs(
-#'     node = 8,
-#'     node_attr = "value",
-#'     tol_abs = c(3, 3))
-#' #> [1]  7  9 10 11 12
+#'     node = 10,
+#'     node_attr = value,
+#'     tol_abs = c(1, 1))
 #'
-#' # That resulted in a fairly large set of 5
-#' # neigboring nodes; For sake of example, setting the
-#' # range to be very large will effectively return all
-#' # nodes in the graph except for the starting node
+#' # That resulted in a fairly large
+#' # set of 4 neigboring nodes; for
+#' # sake of example, setting the range
+#' # to be very large will effectively
+#' # return all nodes in the graph
+#' # except for the starting node
 #' graph %>%
 #'   get_similar_nbrs(
-#'     node = 8,
-#'     node_attr = "value",
+#'     node = 10,
+#'     node_attr = value,
 #'     tol_abs = c(10, 10)) %>%
 #'     length()
-#' #> [1] 13
-#' @importFrom rlang enquo UQ
+#' @importFrom rlang enquo get_expr
 #' @export get_similar_nbrs
 
 get_similar_nbrs <- function(graph,
@@ -82,14 +92,21 @@ get_similar_nbrs <- function(graph,
                              tol_abs = NULL,
                              tol_pct = NULL) {
 
-  node_attr <- rlang::enquo(node_attr)
-  node_attr <- (rlang::UQ(node_attr) %>% paste())[2]
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
 
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
+    # Get the requested `node_attr`
+  node_attr <-
+    rlang::enquo(node_attr) %>% rlang::get_expr() %>% as.character()
+
   # Get value to match on
   match <-
     get_node_df(graph)[
@@ -206,7 +223,7 @@ get_similar_nbrs <- function(graph,
   # Get the final set of nodes that satisfy similarity
   # and adjacency conditions
   matching_nodes <-
-    setdiff(nodes[length(nodes)][[1]], node)
+    base::setdiff(nodes[length(nodes)][[1]], node)
 
   # If there are no matching nodes return `NA`
   if (length(matching_nodes) == 0) {
