@@ -26,11 +26,8 @@
 #' # Get the graph's internal edf
 #' # to show which edge attributes
 #' # are available
-#' get_edge_df(graph)
-#' #>   id from to  rel width
-#' #> 1  1    1  2 <NA>   3.4
-#' #> 2  2    2  3 <NA>   2.3
-#' #> 3  3    3  4 <NA>   7.2
+#' graph %>%
+#'   get_edge_df()
 #'
 #' # Mutate the `width` edge
 #' # attribute, dividing each
@@ -44,11 +41,8 @@
 #' # edf to show that the edge
 #' # attribute `width` had its
 #' # values changed
-#' get_edge_df(graph)
-#' #>   id from to  rel width
-#' #> 1  1    1  2 <NA>  1.70
-#' #> 2  2    2  3 <NA>  1.15
-#' #> 3  3    3  4 <NA>  3.60
+#' graph %>%
+#'   get_edge_df()
 #'
 #' # Create a new edge attribute,
 #' # called `length`, that is the
@@ -64,11 +58,8 @@
 #' # Get the graph's internal edf
 #' # to show that the edge attribute
 #' # values had been mutated
-#' get_edge_df(graph)
-#' #>   id from to  rel width length
-#' #> 1  1    1  2 <NA>  1.70   2.53
-#' #> 2  2    2  3 <NA>  1.15   2.14
-#' #> 3  3    3  4 <NA>  3.60   3.28
+#' graph %>%
+#'   get_edge_df()
 #'
 #' # Create a new edge attribute
 #' # called `area`, which is the
@@ -83,11 +74,8 @@
 #' # to show that the edge attribute
 #' # values had been multiplied
 #' # together (with new attr `area`)
-#' get_edge_df(graph)
-#' #>   id from to  rel width length   area
-#' #> 1  1    1  2 <NA>  1.70   2.53  4.301
-#' #> 2  2    2  3 <NA>  1.15   2.14  2.461
-#' #> 3  3    3  4 <NA>  3.60   3.28 11.808
+#' graph %>%
+#'   get_edge_df()
 #' @importFrom dplyr mutate_
 #' @importFrom rlang exprs
 #' @export mutate_edge_attrs
@@ -98,14 +86,23 @@ mutate_edge_attrs <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Validation: Graph contains edges
   if (graph_contains_edges(graph) == FALSE) {
-    stop("The graph contains no edges, so, no edge attributes can undergo mutation.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph contains no edges")
   }
 
   # Collect expressions
@@ -120,7 +117,10 @@ mutate_edge_attrs <- function(graph,
   if ("id" %in% names(exprs) |
       "from" %in% names(exprs) |
       "to" %in% names(exprs)) {
-    stop("The variables `id`, `from`, or `to` cannot undergo mutation.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The variables `id`, `from`, or `to` cannot undergo mutation")
   }
 
   for (i in 1:length(exprs)) {
@@ -139,7 +139,7 @@ mutate_edge_attrs <- function(graph,
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "mutate_edge_attrs",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
