@@ -61,12 +61,8 @@
 #'     dx = 5, dy = 0)
 #'
 #' # View the graph's node data frame
-#' get_node_df(graph)
-#' #>   id type label x y
-#' #> 1  1    a   one 6 1
-#' #> 2  2    a   two 7 2
-#' #> 3  3    b three 8 3
-#' #> 4  4    b  four 9 4
+#' graph %>%
+#'   get_node_df()
 #'
 #' # Now select nodes that have `type == "b"`
 #' # and move them in the `y` direction 2 units
@@ -81,12 +77,8 @@
 #'     dx = 0, dy = 2)
 #'
 #' # View the graph's node data frame
-#' get_node_df(graph)
-#' #>   id type label x y
-#' #> 1  1    a   one 6 1
-#' #> 2  2    a   two 7 2
-#' #> 3  3    b three 8 5
-#' #> 4  4    b  four 9 6
+#' graph %>%
+#'   get_node_df()
 #' @importFrom dplyr filter case_when coalesce
 #' @export nudge_node_positions_ws
 
@@ -97,37 +89,47 @@ nudge_node_positions_ws <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Validation: Graph contains nodes
   if (graph_contains_nodes(graph) == FALSE) {
-    stop("The graph contains no nodes, so, no nodes can be moved.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph contains no nodes")
   }
 
   # Validation: Graph object has valid node selection
   if (graph_contains_node_selection(graph) == FALSE) {
-    stop("There is no selection of nodes available.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "There is no selection of nodes available.")
   }
 
   # Create bindings for specific variables
   nodes <- x <- y <- id <- NULL
 
-  # Get the graph's node data frame as an object; stop
-  # function if this doesn't exist
-  if (is.null(graph$nodes_df)) {
-    stop("This graph does not contain any nodes.")
-  } else {
-    ndf <- graph$nodes_df
-  }
+  # Get the graph's node data frame as an object
+  ndf <- graph$nodes_df
 
   # If both the `x` and `y` attributes do not exist,
   # stop the function
   if (!("x" %in% colnames(ndf)) |
       !("y" %in% colnames(ndf))) {
-    stop("There are no `x` and `y` attribute values to modify.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "There are no `x` and `y` attribute values to modify")
   }
 
   # Get the current selection of nodes
@@ -144,7 +146,11 @@ nudge_node_positions_ws <- function(graph,
   # vector with those node ID values; otherwise,
   # stop function
   if (nrow(ndf_filtered) == 0) {
-    stop("There are no nodes can be moved to different `x` or `y` locations.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "There are no nodes can be moved to different `x` or `y` locations")
+
   } else {
     nodes <- ndf_filtered$id
   }
@@ -152,33 +158,24 @@ nudge_node_positions_ws <- function(graph,
   # Use `case_when` statements to selectively perform
   # a vectorized `if` statement across all nodes for
   # the `x` and `y` node attribute
-  x_attr_new <-
-    dplyr::case_when(
-      ndf$id == nodes ~ ndf$x + dx,
-      TRUE ~ as.numeric(ndf$x))
+  ndf_new <-
+    ndf %>%
+    dplyr::mutate(x = dplyr::case_when(
+      id %in% as.integer(nodes) ~ x + dx,
+      !(id %in% as.integer(nodes)) ~ x)) %>%
+    dplyr::mutate(y = dplyr::case_when(
+      id %in% nodes ~ y + dy,
+      !(id %in% as.integer(nodes)) ~ y))
 
-  y_attr_new <-
-    dplyr::case_when(
-      ndf$id == nodes ~ ndf$y + dy,
-      TRUE ~ as.numeric(ndf$y))
-
-  # Replace the `x` column to the ndf with a
-  # coalesced version of the column contents
-  ndf$x <- dplyr::coalesce(x_attr_new, ndf$x)
-
-  # Replace the `y` column to the ndf with a
-  # coalesced version of the column contents
-  ndf$y <- dplyr::coalesce(y_attr_new, ndf$y)
-
-  # Replace the graph's node data frame with `ndf`
-  graph$nodes_df <- ndf
+  # Replace the graph's node data frame with `ndf_new`
+  graph$nodes_df <- ndf_new
 
   # Update the `graph_log` df with an action
   graph$graph_log <-
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "nudge_node_positions",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
