@@ -28,7 +28,6 @@
 #' # Get the selection of edges
 #' graph %>%
 #'   get_selection()
-#' #> [1] 1 2
 #'
 #' # Perform another selection of edges,
 #' # with edge IDs `1`, `2`, and `4`
@@ -41,18 +40,16 @@
 #' # Get the selection of edges
 #' graph %>%
 #'   get_selection()
-#' #> [1] 1 2 4
 #'
 #' # Get the fraction of edges selected
 #' # over all the edges in the graph
 #' graph %>%
-#' {
-#'   l <- get_selection(.) %>%
-#'     length(.)
-#'   e <- edge_count(.)
-#'   l/e
-#' }
-#' #> [1] 0.75
+#'   {
+#'     l <- get_selection(.) %>%
+#'       length(.)
+#'     e <- count_edges(.)
+#'     l/e
+#'   }
 #' @importFrom dplyr filter select rename
 #' @export select_edges_by_edge_id
 
@@ -63,14 +60,23 @@ select_edges_by_edge_id <- function(graph,
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Validation: Graph contains edges
   if (graph_contains_edges(graph) == FALSE) {
-    stop("The graph contains no edges, so, no edges can be selected.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph contains no edges")
   }
 
   # Create bindings for specific variables
@@ -79,10 +85,16 @@ select_edges_by_edge_id <- function(graph,
   # Extract the graph's internal edf
   edges_df <- graph$edges_df
 
+  # Filter the edf by the requested edge IDs
   edges_selected <-
     edges_df %>%
     dplyr::filter(id %in% edges)
 
+  # Obtain the input graph's node and edge
+  # selection properties
+  n_e_select_properties_in <-
+    node_edge_selection_properties(graph = graph)
+
   # Create an integer vector representing edges
   edges_selected <- edges_selected$id
 
@@ -100,7 +112,7 @@ select_edges_by_edge_id <- function(graph,
       intersect(edges_prev_selection, edges_selected)
   } else if (set_op == "difference") {
     edges_combined <-
-      setdiff(edges_prev_selection, edges_selected)
+      base::setdiff(edges_prev_selection, edges_selected)
   }
 
   # Filter `edges_df` to provide the correct esdf
@@ -117,12 +129,17 @@ select_edges_by_edge_id <- function(graph,
   # Replace `graph$node_selection` with an empty df
   graph$node_selection <- create_empty_nsdf()
 
+  # Obtain the output graph's node and edge
+  # selection properties
+  n_e_select_properties_out <-
+    node_edge_selection_properties(graph = graph)
+
   # Update the `graph_log` df with an action
   graph$graph_log <-
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "select_edges_by_edge_id",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
@@ -133,5 +150,43 @@ select_edges_by_edge_id <- function(graph,
     save_graph_as_rds(graph = graph)
   }
 
+  # Construct message body
+  if (!n_e_select_properties_in[["node_selection_available"]] &
+      !n_e_select_properties_in[["edge_selection_available"]]) {
+
+    msg_body <-
+      glue::glue(
+        "created a new selection of \\
+        {n_e_select_properties_out[['selection_count_str']]}")
+
+  } else if (n_e_select_properties_in[["node_selection_available"]] |
+             n_e_select_properties_in[["edge_selection_available"]]) {
+
+    if (n_e_select_properties_in[["edge_selection_available"]]) {
+      msg_body <-
+        glue::glue(
+          "modified an existing selection of\\
+           {n_e_select_properties_in[['selection_count_str']]}:
+           * {n_e_select_properties_out[['selection_count_str']]}\\
+           are now in the active selection
+           * used the `{set_op}` set operation")
+    }
+
+    if (n_e_select_properties_in[["node_selection_available"]]) {
+      msg_body <-
+        glue::glue(
+          "created a new selection of\\
+           {n_e_select_properties_out[['selection_count_str']]}:
+           * this replaces\\
+           {n_e_select_properties_in[['selection_count_str']]}\\
+           in the prior selection")
+    }
+  }
+
+  # Issue a message to the user
+  emit_message(
+    fcn_name = fcn_name,
+    message_body = msg_body)
+
   graph
 }
