@@ -1,25 +1,29 @@
-#' Convert graph to an undirected graph
-#' @description Take a graph which is directed and
-#' convert it to an undirected graph.
+#' Convert a directed graph to an undirected graph
+#' @description Take a graph which is
+#' directed and convert it to an undirected
+#' graph.
 #' @param graph a graph object of class
 #' \code{dgr_graph}.
-#' @return a graph object of class \code{dgr_graph}.
+#' @return a graph object of class
+#' \code{dgr_graph}.
 #' @examples
-#' # Create a graph with a directed tree
+#' # Create a graph with a
+#' # directed tree
 #' graph <-
 #'   create_graph() %>%
 #'   add_balanced_tree(
 #'     k = 2, h = 2)
 #'
-#' # Convert this graph from directed to undirected
+#' # Convert this graph from
+#' # directed to undirected
 #' graph <-
 #'   graph %>%
 #'   set_graph_undirected()
 #'
-#' # Perform a check on whether graph is directed
+#' # Perform a check on whether
+#' # graph is directed
 #' graph %>%
 #'   is_graph_directed()
-#' #> [1] FALSE
 #' @export set_graph_undirected
 
 set_graph_undirected <- function(graph) {
@@ -27,14 +31,15 @@ set_graph_undirected <- function(graph) {
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
-  }
 
-  # If graph is already undirected, stop function
-  if (graph$directed == FALSE) {
-    stop("The graph is already undirected.")
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Set the `directed` vector to FALSE
@@ -45,7 +50,7 @@ set_graph_undirected <- function(graph) {
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "set_graph_undirected",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
