@@ -15,6 +15,14 @@
 #' traversed edges. If the edge attribute already exists,
 #' the values will be merged to the traversed edges;
 #' otherwise, a new edge attribute will be created.
+#' @param copy_attrs_as if a node attribute name
+#' is provided in \code{copy_attrs_from}, this option
+#' will allow the copied attribute values to be
+#' written under a different edge attribute name.
+#' If the attribute name provided in
+#' \code{copy_attrs_as} does not exist in the graph's
+#' edf, the new edge attribute will be created
+#' with the chosen name.
 #' @param agg if a node attribute is provided
 #' to \code{copy_attrs_from}, then an aggregation
 #' function is required since there may be cases where
@@ -23,7 +31,8 @@
 #' the following aggregation functions can be used:
 #' \code{sum}, \code{min}, \code{max}, \code{mean}, or
 #' \code{median}.
-#' @return a graph object of class \code{dgr_graph}.
+#' @return a graph object of class
+#' \code{dgr_graph}.
 #' @examples
 #' # Set a seed
 #' set.seed(23)
@@ -59,13 +68,8 @@
 #'   join_edge_attrs(df = df)
 #'
 #' # Show the graph's internal edge data frame
-#' get_edge_df(graph)
-#' #>   id from to  rel values
-#' #> 1  1    1  2 <NA>   6.00
-#' #> 2  2    1  3    A   6.11
-#' #> 3  3    2  4    B   4.72
-#' #> 4  4    2  5    C   6.02
-#' #> 5  5    3  5    D   5.05
+#' graph %>%
+#'   get_edge_df()
 #'
 #' # Perform a simple traversal from nodes to
 #' # adjacent edges with no conditions on the
@@ -74,7 +78,6 @@
 #'   select_nodes_by_id(nodes = 3) %>%
 #'   trav_both_edge() %>%
 #'   get_selection()
-#' #> [1] 2 5
 #'
 #' # Traverse from node `2` to any adjacent
 #' # edges, filtering to those edges that have
@@ -84,7 +87,6 @@
 #'   trav_both_edge(
 #'     conditions = is.na(rel)) %>%
 #'   get_selection()
-#' #> [1] 1
 #'
 #' # Traverse from node `2` to any adjacent
 #' # edges, filtering to those edges that have
@@ -95,7 +97,6 @@
 #'   trav_both_edge(
 #'     conditions = values > 6.5) %>%
 #'   get_selection()
-#' #> [1] 2
 #'
 #' # Traverse from node `5` to any adjacent
 #' # edges, filtering to those edges that
@@ -106,7 +107,6 @@
 #'   trav_both_edge(
 #'     conditions = rel == "C") %>%
 #'   get_selection()
-#' #> [1] 4
 #'
 #' # Traverse from node `2` to any adjacent
 #' # edges, filtering to those edges that
@@ -117,7 +117,6 @@
 #'   trav_both_edge(
 #'     conditions = rel %in% c("B", "C")) %>%
 #'   get_selection()
-#' #> [1] 3 4
 #'
 #' # Traverse from node `2` to any adjacent
 #' # edges, and use multiple conditions for the
@@ -129,7 +128,6 @@
 #'       rel %in% c("B", "C") &
 #'       values > 4.0) %>%
 #'   get_selection()
-#' #> [1] 3 4
 #'
 #' # Traverse from node `2` to any adjacent
 #' # edges, and use multiple conditions with
@@ -141,7 +139,6 @@
 #'       rel %in% c("B", "C") |
 #'       values > 4.0) %>%
 #'   get_selection()
-#' #> [1] 1 3 4
 #'
 #' # Traverse from node `2` to any adjacent
 #' # edges, and use a regular expression as
@@ -151,7 +148,6 @@
 #'   trav_both_edge(
 #'     conditions = grepl("B|C", rel)) %>%
 #'   get_selection()
-#' #> [1] 3 4
 #'
 #' # Create another simple graph to demonstrate
 #' # copying of node attribute values to traversed
@@ -167,19 +163,11 @@
 #' # Show the graph's internal edge data frame
 #' graph %>%
 #'   get_edge_df()
-#' #>   id from to  rel
-#' #> 1  1    1  2 <NA>
-#' #> 2  2    2  3 <NA>
-#' #> 3  3    3  4 <NA>
+
 #'
 #' # Show the graph's internal node data frame
 #' graph %>%
 #'   get_node_df()
-#' #>   id type label value
-#' #> 1  1 <NA>     1    NA
-#' #> 2  2 <NA>     2     5
-#' #> 3  3 <NA>     3     5
-#' #> 4  4 <NA>     4    NA
 #'
 #' # Perform a traversal from the nodes to
 #' # the adjacent edges while also applying
@@ -197,51 +185,82 @@
 #' # after this change
 #' graph %>%
 #'   get_edge_df()
-#' #>   id from to  rel value
-#' #> 1  1    1  2 <NA>     5
-#' #> 2  2    2  3 <NA>    10
-#' #> 3  3    3  4 <NA>     5
 #' @importFrom stats median
 #' @importFrom dplyr filter select select_ left_join right_join rename bind_rows group_by summarize_
 #' @importFrom tibble as_tibble
-#' @importFrom rlang enquo UQ
+#' @importFrom rlang enquo UQ get_expr
 #' @export trav_both_edge
 
 trav_both_edge <- function(graph,
                            conditions = NULL,
                            copy_attrs_from = NULL,
+                           copy_attrs_as = NULL,
                            agg = "sum") {
 
-  conditions <- rlang::enquo(conditions)
-
-  copy_attrs_from <- rlang::enquo(copy_attrs_from)
-  copy_attrs_from <- (rlang::UQ(copy_attrs_from) %>% paste())[2]
-
-  if (copy_attrs_from == "NULL") {
-    copy_attrs_from <- NULL
-  }
-
   # Get the time of function start
   time_function_start <- Sys.time()
 
+  # Get the name of the function
+  fcn_name <- get_calling_fcn()
+
   # Validation: Graph object is valid
   if (graph_object_valid(graph) == FALSE) {
-    stop("The graph object is not valid.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph object is not valid")
   }
 
   # Validation: Graph contains nodes
   if (graph_contains_nodes(graph) == FALSE) {
-    stop("The graph contains no nodes, so, no traversal can occur.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph contains no nodes")
   }
 
   # Validation: Graph contains edges
   if (graph_contains_edges(graph) == FALSE) {
-    stop("The graph contains no edges, so, no traversal can occur.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = "The graph contains no edges")
   }
 
   # Validation: Graph object has valid node selection
   if (graph_contains_node_selection(graph) == FALSE) {
-    stop("There is no selection of nodes, so, no traversal can occur.")
+
+    emit_error(
+      fcn_name = fcn_name,
+      reasons = c(
+        "There is no selection of nodes available.",
+        "any traversal requires an active selection",
+        "this type of traversal requires a selection of nodes"))
+  }
+
+  # Capture provided conditions
+  conditions <- rlang::enquo(conditions)
+
+  # Get the requested `copy_attrs_from`
+  copy_attrs_from <-
+    rlang::enquo(copy_attrs_from) %>% rlang::get_expr() %>% as.character()
+
+  # Get the requested `copy_attrs_as`
+  copy_attrs_as <-
+    rlang::enquo(copy_attrs_as) %>% rlang::get_expr() %>% as.character()
+
+  if (length(copy_attrs_from) == 0) {
+    copy_attrs_from <- NULL
+  }
+
+  if (length(copy_attrs_as) == 0) {
+    copy_attrs_as <- NULL
+  }
+
+  if (!is.null(copy_attrs_as) & !is.null(copy_attrs_from)) {
+    if (copy_attrs_as == copy_attrs_from) {
+      copy_attrs_as <- NULL
+    }
   }
 
   # Create bindings for specific variables
@@ -269,10 +288,12 @@ trav_both_edge <- function(graph,
   # If traversal conditions are provided then
   # pass in those conditions and filter the
   # data frame of `valid_edges`
-  if (!((rlang::UQ(conditions) %>% paste())[2] == "NULL")) {
+  if (!is.null(
+    rlang::enquo(conditions) %>%
+    rlang::get_expr())) {
 
     valid_edges <-
-      filter(
+      dplyr::filter(
         .data = valid_edges,
         rlang::UQ(conditions))
   }
@@ -313,6 +334,20 @@ trav_both_edge <- function(graph,
           by = c("id" = "to")) %>%
         dplyr::select_("e_id", copy_attrs_from)
 
+      if (!is.null(copy_attrs_as)) {
+
+        if (copy_attrs_as %in% c("id", "from", "to")) {
+
+          emit_error(
+            fcn_name = fcn_name,
+            reasons = "Copied attributes should not overwrite either of the `id`, `from`, or `to` edge attributes")
+        }
+
+        colnames(from_join)[2] <-
+          colnames(to_join)[2] <-
+          copy_attrs_from <- copy_attrs_as
+      }
+
       edges <-
         dplyr::bind_rows(
           from_join, to_join) %>%
@@ -333,7 +368,22 @@ trav_both_edge <- function(graph,
       from_join <-
         ndf %>%
         dplyr::select_("id", copy_attrs_from) %>%
-        dplyr::filter(id %in% starting_nodes) %>%
+        dplyr::filter(id %in% starting_nodes)
+
+      if (!is.null(copy_attrs_as)) {
+
+        if (copy_attrs_as %in% c("id", "from", "to")) {
+
+          emit_error(
+            fcn_name = fcn_name,
+            reasons = "Copied attributes should not overwrite either of the `id`, `from`, or `to` edge attributes")
+        }
+
+        colnames(from_join)[2] <- copy_attrs_as
+      }
+
+      from_join <-
+        from_join %>%
         dplyr::right_join(
           valid_edges %>%
             dplyr::select(-rel) %>%
@@ -366,13 +416,26 @@ trav_both_edge <- function(graph,
       to_join <-
         ndf %>%
         dplyr::select_("id", copy_attrs_from) %>%
-        dplyr::filter(id %in% starting_nodes) %>%
+        dplyr::filter(id %in% starting_nodes)
+
+      if (!is.null(copy_attrs_as)) {
+
+        colnames(to_join)[2] <- copy_attrs_as
+      }
+
+      to_join <-
+        to_join %>%
         dplyr::right_join(
           valid_edges %>%
             dplyr::select(-rel) %>%
             dplyr::rename(e_id = id),
           by = c("id" = "to"))
 
+      if (!is.null(copy_attrs_as)) {
+
+        copy_attrs_from <- copy_attrs_as
+      }
+
       # Get column numbers that end with ".x" or ".y"
       split_var_x_col <-
         which(grepl("\\.x$", colnames(to_join)))
@@ -482,7 +545,7 @@ trav_both_edge <- function(graph,
     add_action_to_log(
       graph_log = graph$graph_log,
       version_id = nrow(graph$graph_log) + 1,
-      function_used = "trav_both_edge",
+      function_used = fcn_name,
       time_modified = time_function_start,
       duration = graph_function_duration(time_function_start),
       nodes = nrow(graph$nodes_df),
