@@ -1,6 +1,6 @@
 context("data.table and dplyr integration")
 
-test_that("combine_edges",{
+test_that("combine_edges", {
 
   # Create `edges_1` edge data frame
   edges_1 <-
@@ -26,25 +26,29 @@ test_that("combine_edges",{
   class(edges_2) <-
     c("data.table", "tbl_df", class(edges_2))
 
-  # Combine the 2 edge data frames
-  expect_warning(combine_edfs(edges_1, edges_2),
-                 regexp = NA)
+  expect_warning(
+    combine_edfs(edges_1, edges_2),
+    regexp = NA)
 
+  # Combine the 2 edge data frames
   all_edges <- combine_edfs(edges_1, edges_2)
 
   # Expect that a data frame is generated
-  expect_is(all_edges, "data.frame")
+  expect_is(
+    all_edges, "data.frame")
 
   # Expect that the combined edge data frame
   # has 8 rows
-  expect_equal(nrow(all_edges), 8)
+  expect_equal(
+    nrow(all_edges), 8)
 
   # Expect that the combined edge data frame
   # has 7 columns
-  expect_equal(ncol(all_edges), 7)
+  expect_equal(
+    ncol(all_edges), 7)
 })
 
-test_that("create_graph",{
+test_that("create_graph", {
 
   # Create a node data frame
   nodes <-
@@ -60,19 +64,30 @@ test_that("create_graph",{
   class(nodes) <-
     c("data.table", "tbl_df", class(nodes))
 
-  # Create the graph object using the node data frame
-  expect_warning(create_graph(nodes_df = nodes),
-                 regexp = NA)
+  expect_warning(
+    create_graph(
+      nodes_df = nodes),
+    regexp = NA)
 
+  # Create the graph object using the node data frame
   graph <- create_graph(nodes_df = nodes)
 
   # Expect that names in this graph object match a
   # prescribed set of names
   expect_true(
-    all(names(graph) ==
-          c("graph_info", "nodes_df", "edges_df",
-            "global_attrs", "directed",
-            "last_node", "last_edge",
-            "node_selection", "edge_selection",
-            "graph_log")))
+    all(
+      names(graph) ==
+        c(
+          "graph_info",
+          "nodes_df",
+          "edges_df",
+          "global_attrs",
+          "directed",
+          "last_node",
+          "last_edge",
+          "node_selection",
+          "edge_selection",
+          "cache",
+          "graph_actions",
+          "graph_log")))
 })
